@@ -8,7 +8,7 @@ export const surveyResponse = express.Router();
 surveyResponse.get(
   '/:id',
   asyncHandler(async (req, res) => {
-    const { models, params } = req;
+    const { models, params, query } = req;
     req.checkPermission('read', 'SurveyResponse');
 
     const surveyResponseRecord = await models.SurveyResponse.findByPk(params.id);
@@ -28,6 +28,13 @@ surveyResponse.get(
       notTransformDate: true,
     });
 
+    await req.audit.access({
+      recordId: surveyResponseRecord.id,
+      params,
+      model: models.SurveyResponse,
+      facilityId: query.facilityId,
+    });
+
     res.send({
       ...surveyResponseRecord.forResponse(),
       components,
@@ -54,7 +61,7 @@ surveyResponse.post(
       settings,
     } = req;
     // Responses for the vitals survey will check against 'Vitals' create permissions
-    // All others will check against 'SurveyResponse' create permissions
+    // All others witll check against 'SurveyResponse' create permissions
     const noun = await models.Survey.getResponsePermissionCheck(body.surveyId);
     req.checkPermission('create', noun);
 
